@@ -139,8 +139,8 @@ Proceed with the download?"
         # parse the package's origin
         if not self.candidate.downloadable:
             origin = "local_package"
-        elif self.candidate.origin == "Pearl":
-            origin = "Pearl"
+        elif self.candidate.origin == "pearllinux":
+            origin = "pearllinux"
         elif self.candidate.origin.startswith("LP-PPA-"):
             origin = "LP-PPA"
         elif self.apt_origins and self.candidate.origin in self.apt_origins.list():
@@ -175,7 +175,7 @@ Proceed with the download?"
             if not r:
                 self.exit_on_fail(2)
         # Pearl Linux repo
-        elif origin == 'Pearl':
+        elif origin == 'pearllinux':
             # Pearl repos don't have .debian.tar.xz files, only full packages, so
             # check the package cache first
             base_uri, _ = os.path.split(self.candidate.uri)
@@ -184,7 +184,7 @@ Proceed with the download?"
                 # fall back to last change info for the source package
                 # Pearl's naming scheme seems to be using amd64 unless source
                 # is i386 only, we always check amd64 first
-                base_uri = "http://packages.pearllinux.com/dev/%s_%s_%s.changes"
+                base_uri = "http://packages.pearllinux.net/dev/%s_%s_%s.changes"
                 uri = base_uri % (self.candidate.source_name,
                     self.candidate.source_version, "amd64")
                 r = self.check_url(uri, False)
